==> haskell-foldable1-classes-compat-0.1.2-54.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-foldable1-classes-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:               foldable1-classes-compat
version:            0.1.2
visibility:         public
id:                 foldable1-classes-compat-0.1.2-8gVwt1MfUMrN4OXJXlWih
key:                foldable1-classes-compat-0.1.2-8gVwt1MfUMrN4OXJXlWih
license:            BSD-3-Clause
maintainer:         Ryan Scott <ryan.gl.scott@gmail.com>
author:             Edward Kmett, Oleg Grenrus
homepage:           https://github.com/haskell-compat/foldable1-classes-compat
synopsis:
    Compatibility package for the Foldable1 and Bifoldable1 type classes

description:
    A compatibility package for the @Foldable1@ and @Bifoldable1@ type classes,
    which were introduced in @base-4.18.0.0@ (GHC 9.6.1). For more information,
    see <https://github.com/haskell/core-libraries-committee/issues/9 this Core
    Libraries Committee proposal>.

    @Foldable1@ and @Bifoldable1@ classify non-empty data structures that can be
    folded to a summary value.

category:           Data, Compatibility
abi:                6f78e70309fb6303857b6a05d0c7aa3c
exposed:            True
data-dir:           /usr/share/haskell-foldable1-classes-compat
depends:
    base-4.18.2.1 ghc-prim-0.10.0 tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig

haddock-interfaces:
    /usr/share/doc/haskell-foldable1-classes-compat/html/foldable1-classes-compat.haddock

haddock-html:       /usr/share/doc/haskell-foldable1-classes-compat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foldable1-classes-compat-0.1.2-56-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-foldable1-classes-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:               foldable1-classes-compat
version:            0.1.2
visibility:         public
id:                 foldable1-classes-compat-0.1.2-J5kwm1533Cj4GyXhvcJDi9
key:                foldable1-classes-compat-0.1.2-J5kwm1533Cj4GyXhvcJDi9
license:            BSD-3-Clause
maintainer:         Ryan Scott <ryan.gl.scott@gmail.com>
author:             Edward Kmett, Oleg Grenrus
homepage:           https://github.com/haskell-compat/foldable1-classes-compat
synopsis:
    Compatibility package for the Foldable1 and Bifoldable1 type classes

description:
    A compatibility package for the @Foldable1@ and @Bifoldable1@ type classes,
    which were introduced in @base-4.18.0.0@ (GHC 9.6.1). For more information,
    see <https://github.com/haskell/core-libraries-committee/issues/9 this Core
    Libraries Committee proposal>.

    @Foldable1@ and @Bifoldable1@ classify non-empty data structures that can be
    folded to a summary value.

category:           Data, Compatibility
abi:                6f78e70309fb6303857b6a05d0c7aa3c
exposed:            True
data-dir:           /usr/share/haskell-foldable1-classes-compat
depends:
    base-4.18.2.1 ghc-prim-0.10.0 tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig

haddock-interfaces:
    /usr/share/doc/haskell-foldable1-classes-compat/html/foldable1-classes-compat.haddock

haddock-html:       /usr/share/doc/haskell-foldable1-classes-compat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
